pub struct RequestLayer;Trait Implementations
Sourceimpl Clone for RequestLayer
impl Clone for RequestLayer
Sourcefn clone(&self) -> RequestLayer
fn clone(&self) -> RequestLayer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestLayer
impl Debug for RequestLayer
Sourceimpl Default for RequestLayer
impl Default for RequestLayer
Sourcefn default() -> RequestLayer
fn default() -> RequestLayer
Returns the “default value” for a type. Read more
Sourceimpl Hash for RequestLayer
impl Hash for RequestLayer
Sourceimpl<S> Layer<S> for RequestLayer
impl<S> Layer<S> for RequestLayer
Sourcetype Service = RequestService<S>
type Service = RequestService<S>
The service produced by the layer.
Sourcefn layer(&self, inner: S) -> Self::Service
fn layer(&self, inner: S) -> Self::Service
Wrap the given service with the middleware, returning a new service.
Sourcefn into_layer(self, inner: S) -> Self::Service
fn into_layer(self, inner: S) -> Self::Service
Same as
layer but consuming self after the service was created. Read moreSourceimpl Ord for RequestLayer
impl Ord for RequestLayer
Sourcefn cmp(&self, other: &RequestLayer) -> Ordering
fn cmp(&self, other: &RequestLayer) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RequestLayer
impl PartialEq for RequestLayer
Sourceimpl PartialOrd for RequestLayer
impl PartialOrd for RequestLayer
impl Copy for RequestLayer
impl Eq for RequestLayer
impl StructuralPartialEq for RequestLayer